@@ -308,9 +308,10 @@
 	    ;; hacks for use in util2.scm:canize-enum-def-list:
 	    ;; If ident is defined then it should have already been expanded.
 	    ;; So then only enum defs remain which should be valid expressions.
-	    ((ident) (or (and=> (assoc-ref dict (tx1 tree)) string->number) 0))
-	    ((p-expr) (ev1 tree))
-	    ((cast) (ev2 tree))
+	    ;; I think no longer needed since we use cxeval now.
+	    ;;((ident) (or (and=> (assoc-ref dict (tx1 tree)) string->number) 0))
+	    ;;((p-expr) (ev1 tree))
+	    ;;((cast) (ev2 tree))
 	    (else (error "nyacc eval-cpp-expr: incomplete implementation"))))))
     (eval-expr tree)))
 
